@@ -7,8 +7,9 @@ use Net::OAuth;
 use URI;
 use Encode qw(encode_utf8);
 
-our @ISA = qw(HTTP::Request);
-our $VERSION = '1.16';
+use parent qw(HTTP::Request);
+
+our $VERSION = '1.17';
 
 sub new {
     my $class = shift;
